@@ -860,6 +860,20 @@ class RedisUtil:
         key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         return cls.CONN.exists(key)
 
+    @classmethod
+    def expire(cls, key: str, secs: int):
+        """设置key的失效时间
+        """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
+        return cls.CONN.expire(key, secs)
+
+    @classmethod
+    def delete(cls, key: str):
+        """删除key
+        """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
+        return cls.CONN.delete(key)
+
     @classmethod
     def get(cls, key: str):
         """字符串获取值
